@@ -1,10 +1,7 @@
 from enum import Enum
 from typing import Dict, Sequence
 
-try:
-    import pandas as pd
-except ImportError:
-    pass
+import pandas as pd
 
 from calcbench.api_client import (
     _json_POST,
