@@ -1,5 +1,5 @@
 import warnings
-from datetime import date, datetime
+from datetime import date
 from typing import Any, Optional, Sequence, TYPE_CHECKING, Union
 
 from calcbench.api_query_params import (
@@ -72,26 +72,25 @@ class StandardizedPoint(TypedDict):
 def standardized_raw(
     company_identifiers: CompanyIdentifiers = [],
     metrics: Sequence[str] = [],
-    start_year: Optional[int] = None,
+    start_year: int = None,
     start_period: PeriodArgument = None,
-    end_year: Optional[int] = None,
+    end_year: int = None,
     end_period: PeriodArgument = None,
     entire_universe=False,
-    accession_id: Optional[int] = None,
+    accession_id: int = None,
     point_in_time: bool = False,
     include_trace: bool = False,
-    update_date: Optional[date] = None,
+    update_date: date = None,
     all_history=False,
-    year: Optional[int] = None,
+    year: int = None,
     period: PeriodArgument = None,
-    period_type: Optional[PeriodType] = None,
+    period_type: PeriodType = None,
     include_preliminary: bool = False,
     use_fiscal_period: bool = False,
     all_face: bool = False,
     all_footnotes: bool = False,
     include_xbrl: bool = False,
-    filing_id: Optional[int] = None,
-    all_non_GAAP: bool = False,
+    exclude_errors: bool = True,
 ) -> Sequence[StandardizedPoint]:
     """Standardized data.
 
@@ -110,7 +109,6 @@ def standardized_raw(
     :param period_type: Either "annual" or "quarterly"
     :param include_preliminary: Include data from non-XBRL 8-Ks and press releases.
     :param exclude_errors: Run another level of error detections, only works for PIT preliminary
-    :param filing_id: Filing id for which to get data.  corresponds to the filing_id in the objects returned by the filings API.
     :return: A list of dictionaries with keys ['ticker', 'calendar_year', 'calendar_period', 'metric', 'value'].
 
     """
@@ -118,10 +116,9 @@ def standardized_raw(
         bool(company_identifiers),
         bool(entire_universe),
         bool(accession_id),
-        bool(filing_id),
     ].count(True) != 1:
         raise ValueError(
-            "Must pass either company_identifiers, accession id, filing_id, or entire_universe=True"
+            "Must pass either company_identifiers and accession id or entire_universe=True"
         )
     if not any(
         [
@@ -130,14 +127,13 @@ def standardized_raw(
             update_date,
             year,
             accession_id,
-            filing_id,
             all_history,
             period_type,
         ]
     ):
         raise ValueError("Need to specify a period qualifier")
 
-    if (accession_id or filing_id) and any(
+    if accession_id and any(
         [
             company_identifiers,
             start_year,
@@ -150,7 +146,7 @@ def standardized_raw(
         ]
     ):
         raise ValueError(
-            "Accession/Filing IDs are specific to a filing, no other qualifiers make sense."
+            "Accession IDs are specific to a filing, no other qualifiers make sense."
         )
 
     if period is not None:
@@ -187,11 +183,6 @@ def standardized_raw(
             "specifying metrics with all_face or all_footnotes does not make sense"
         )
 
-    if not any([all_face, all_footnotes, metrics, filing_id, all_non_GAAP]):
-        raise ValueError(
-            "need to specify a metrics argument, 'all_face', 'all_foonotes', 'all_non_GAAP' or a metric"
-        )
-
     if isinstance(metrics, str):
         raise TypeError("metrics should be a list of strings")
 
@@ -231,7 +222,7 @@ def standardized_raw(
             "allFootnotes": all_footnotes,
             "allface": all_face,
             "includeXBRL": include_xbrl,
-            "allNonGAAP": all_non_GAAP,
+            "excludeErrors": exclude_errors,
         },
         "periodParameters": {
             "year": start_year,
@@ -243,7 +234,6 @@ def standardized_raw(
             "periodType": period_type,
             "useFiscalPeriod": use_fiscal_period,
             "accessionID": accession_id,
-            "filingID": filing_id,
         },
         "companiesParameters": {
             "entireUniverse": entire_universe,
@@ -260,45 +250,32 @@ def point_in_time(
     metrics: Sequence[str] = [],
     all_history: bool = False,
     entire_universe: bool = False,
-    start_year: Optional[int] = None,
+    start_year: int = None,
     start_period: PeriodArgument = None,
-    end_year: Optional[int] = None,
+    end_year: int = None,
     end_period: PeriodArgument = None,
-    period_type: Optional[PeriodType] = None,
+    period_type: PeriodType = None,
     use_fiscal_period: bool = False,
     include_preliminary: bool = False,
     all_face: bool = False,
     include_xbrl: bool = True,
-    accession_id: Optional[int] = None,
+    accession_id: int = None,
     include_trace: bool = False,
     set_index: bool = False,
-    _point_in_time_mode=True,
-    filing_id: Optional[int] = None,
-    all_non_GAAP: bool = False,
+    exclude_errors: bool = False,
 ) -> "pd.DataFrame":
     """Point-in-Time Data
 
-    Standardized data with a timestamp when it was published by Calcbench.
+    Standardized data with a timestamp when it was published by Calcbench
 
-
-    A record is returned for each filing in which a metric value changed (was revised).
-
-    If the company files an 8-K with revenue = $100 then a week later files a 10-K with revenue = $100 one record will be returned for that period.  It will have preliminary=True and XBRL=True.
-
-    If the company files an 8-K with revenue = $100 and then a week later files a 10-K with revenue = $200, two records will be returned.  One with revenue = $100, a revision_number=0, date_reported of 8-K, preliminary=True and XBRL=False.  You will see a second line with revenue = $200, a revision_number=1, and date_reported of the 10-K, preliminary=False and XBRL=False.
-
-    If the value is revised in subsequent XBRL filings you will see a record for each filing with an incremented revision number.
-
-    :param accession_id: Unique identifier for the filing for which to recieve data.  Pass this to recieve data for one filing.  Same as calcbench_id in filings objects
+    :param accession_id: Unique identifier for the filing for which to recieve data.  Pass this to recieve data for one filing.  Same as filing_id in filings objects
     :param all_face: Retrieve all of the points from the face financials, income/balance/statement of cash flows
     :param all_footnotes: Retrive all of the points from the footnotes to the financials
     :param include_preliminary: Include facts from non-XBRL earnings press-releases and 8-Ks.
     :param include_xbrl: Include facts from XBRL 10-K/Qs.
     :param include_trace: Include a URL that points to the source document.
     :param set_index: Set a useful index on the returned DataFrame
-    :param _point_in_time_mode: DO NOT USE.  For debugging only.
-    :param filing_id: Filing id for which to get data.  corresponds to the filing_id in the objects returned by the filings API.
-    :param all_non_GAAP: include all non-GAAP metrics from earnings press releases such as EBITDA_NonGAAP.  This is implied when querying by `filing_id`.
+    :param exclude_errors:  Run the error detection
     :return: DataFrame of facts
 
     Columns:
@@ -308,18 +285,12 @@ def point_in_time(
        The value of the fact
     revision_number
        0 indicates an original, unrevised value for this fact. 1, 2, 3... indicates subsequent revisions to the fact value.  https://knowledge.calcbench.com/hc/en-us/search?utf8=%E2%9C%93&query=revisions&commit=Search
-    preliminary
-        True indicates the number was parsed from non-XBRL 8-K or press release from the wire
-    XBRL
-        Indicates the number was parsed from XBRL
     period_start
        First day of the fiscal period for this fact
     period_end
        Last day of the fiscal period for this fact
     date_reported
-       Timestamp (EST) when Calcbench published this fact.
-
-       In some cases, particularly prior to 2015, this will be the filing date of the document as recorded by the SEC.  To exclude these points remove points where the hour is 0.
+       Timestamp when Calcbench published this fact
     metric
        The metric name, see the definitions @ https://www.calcbench.com/home/standardizedmetrics
     calendar_year
@@ -356,7 +327,7 @@ def point_in_time(
         company_identifiers=company_identifiers,
         all_face=all_face,
         all_footnotes=all_footnotes,
-        point_in_time=_point_in_time_mode,
+        point_in_time=True,
         metrics=metrics,
         all_history=all_history,
         entire_universe=entire_universe,
@@ -370,8 +341,7 @@ def point_in_time(
         accession_id=accession_id,
         include_trace=include_trace,
         include_xbrl=include_xbrl,
-        filing_id=filing_id,
-        all_non_GAAP=all_non_GAAP,
+        exclude_errors=exclude_errors,
     )
 
     if not data:
@@ -404,7 +374,6 @@ def point_in_time(
     new_columns = list(set(data.columns) - set(ordered_columns))
     data = data.reindex(columns=ordered_columns + new_columns)
     data = data.drop(columns=["trace_facts"], errors="ignore")  # type: ignore
-    data["date_downloaded"] = datetime.now()
     sort_columns = ["ticker", "metric"]
 
     if "calendar_period" in data.columns:
@@ -434,9 +403,7 @@ def point_in_time(
             elif period_type == PeriodType.Annual:
                 data["period"] = pd.PeriodIndex(data["fiscal_year"], freq="A")
         data.drop(["fiscal_year", "fiscal_period"], axis=1, inplace=True)
-        data = data.set_index(
-            ["ticker", "metric", "period", "date_reported"]
-        ).sort_index()
+        data = data.set_index(["ticker", "metric", "period", "revision_number"])
     else:
         data = data.sort_values(sort_columns).reset_index(drop=True)
     return data
@@ -445,20 +412,20 @@ def point_in_time(
 def standardized_data(
     company_identifiers: CompanyIdentifiers = [],
     metrics: Sequence[str] = [],
-    start_year: Optional[int] = None,
+    start_year: int = None,
     start_period: PeriodArgument = None,
-    end_year: Optional[int] = None,
+    end_year: int = None,
     end_period: PeriodArgument = None,
     entire_universe: bool = False,
     point_in_time: bool = False,
-    year: Optional[int] = None,
+    year: int = None,
     period: PeriodArgument = None,
     all_history: bool = False,
-    period_type: Optional[PeriodType] = None,
+    period_type: PeriodType = None,
     trace_hyperlinks: bool = False,
     use_fiscal_period: bool = False,
     company_identifier_scheme: CompanyIdentifierScheme = CompanyIdentifierScheme.Ticker,
-    accession_id: Optional[int] = None,
+    accession_id: int = None,
 ) -> "pd.DataFrame":
     """Standardized Data.
 
